# PyOptimum

This is a library to facilitate access to the 
[Optimize API](https://optimize.vicbee.net/api/ui) in Python.

## Installation

Install with pip by typing:

    pip install pyoptimum

## Documentation

Documentation is available at [read the docs](https://pyoptimum.readthedocs.io).

See [Optimize API](https://optimize.vicbee.net/api/ui) for details on the api calls.
